@@ -7,7 +7,7 @@
  * @date   2007-05-02
  * @brief  RAW file identification information container
  *
- * @author Copyright (C) 2007-2012 by Gilles Caulier
+ * @author Copyright (C) 2007-2013 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  *
  * This program is free software; you can redistribute it
@@ -50,7 +50,7 @@ DcrawInfoContainer::DcrawInfoContainer()
     cameraMult[3]     = 0.0;
     blackPoint        = 0;
 
-    for (int ch=0; ch<8; ch++)
+    for (int ch=0; ch<4; ch++)
     {
         blackPointCh[ch] = 0;
     }
@@ -66,7 +66,7 @@ DcrawInfoContainer::DcrawInfoContainer()
         {
             cameraColorMatrix1[x][y] = 0.0;
             cameraColorMatrix2[x][y] = 0.0;
-            cameraXYZMatrix[y][x]    = 0.0;       // NOTE: see B.K.O # 253911 : [y][x] not [x][y]
+            cameraXYZMatrix[y][x]    = 0.0;       // NOTE: see bug # 253911 : [y][x] not [x][y]
         }
     }
 }
@@ -94,10 +94,6 @@ bool DcrawInfoContainer::isEmpty()
         blackPointCh[1]  == 0           &&
         blackPointCh[2]  == 0           &&
         blackPointCh[3]  == 0           &&
-        blackPointCh[4]  == 0           &&
-        blackPointCh[5]  == 0           &&
-        blackPointCh[6]  == 0           &&
-        blackPointCh[7]  == 0           &&
         whitePoint       == 0           &&
         topMargin        == 0           &&
         leftMargin       == 0           &&
