@@ -7,9 +7,9 @@
  * @date   2006-12-09
  * @brief  a tread-safe libraw C++ program interface
  *
- * @author Copyright (C) 2006-2012 by Gilles Caulier
+ * @author Copyright (C) 2006-2013 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2012 by Marcel Wiesweg
+ * @author Copyright (C) 2006-2013 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
  * @author Copyright (C) 2007-2008 by Guillaume Castagnino
  *         <a href="mailto:casta at xwing dot info">casta at xwing dot info</a>
@@ -36,6 +36,7 @@
 
 // Qt includes
 
+#include <QtCore/QBuffer>
 #include <QtCore/QString>
 #include <QtCore/QObject>
 #include <QtGui/QImage>
@@ -71,28 +72,53 @@ public:
      */
     static QString version();
 
-    /** This is a non cancelable method witch do not require a class instance to run.
-        It can loadEmbeddedPreview() in first and if it failed, call loadHalfPreview().
+    /** Get the preview of RAW picture as a QImage.
+        It tries loadEmbeddedPreview() first and if it fails, calls loadHalfPreview().
      */
     static bool loadRawPreview(QImage& image, const QString& path);
 
-    /** Get the embedded JPEG preview image from RAW picture as a QByteArray witch will include Exif Data.
-        This is a fast and non cancelable. This method do not require a class instance to run.
+    /** Get the preview of RAW picture as a QByteArray holding JPEG data.
+        It tries loadEmbeddedPreview() first and if it fails, calls loadHalfPreview().
+     */
+    static bool loadRawPreview(QByteArray& imgData, const QString& path);
+
+    /** Get the preview of RAW picture passed in QBuffer as a QByteArray holding JPEG data.
+        It tries loadEmbeddedPreview() first and if it fails, calls loadHalfPreview().
+     */
+    static bool loadRawPreview(QByteArray& imgData, const QBuffer& inBuffer);
+
+    /** Get the embedded JPEG preview image from RAW picture as a QByteArray which will include Exif Data.
+        This is fast and non cancelable. This method does not require a class instance to run.
      */
     static bool loadEmbeddedPreview(QByteArray& imgData, const QString& path);
 
-    /** Get the embedded JPEG preview image from RAW picture has a QImage. This is a fast and non cancelable
-        This method do not require a class instance to run.
+    /** Get the embedded JPEG preview image from RAW picture as a QImage. This is fast and non cancelable
+        This method does not require a class instance to run.
      */
     static bool loadEmbeddedPreview(QImage& image, const QString& path);
 
-    /** Get the half decoded RAW picture. This is a more slower than loadEmbeddedPreview() method
-        and non cancelable. This method do not require a class instance to run.
+    /** Get the embedded JPEG preview image from RAW image passed in QBuffer as a QByteArray which will include Exif Data.
+        This is fast and non cancelable. This method does not require a class instance to run.
+     */
+    static bool loadEmbeddedPreview(QByteArray& imgData, const QBuffer& inBuffer);
+
+    /** Get the half decoded RAW picture. This is slower than loadEmbeddedPreview() method
+        and non cancelable. This method does not require a class instance to run.
      */
     static bool loadHalfPreview(QImage& image, const QString& path);
 
+    /** Get the half decoded RAW picture as JPEG data in QByteArray. This is slower than loadEmbeddedPreview()
+        method and non cancelable. This method does not require a class instance to run.
+     */
+    static bool loadHalfPreview(QByteArray& imgData, const QString& path);
+
+    /** Get the half decoded RAW picture passed in QBuffer as JPEG data in QByteArray. This is slower than loadEmbeddedPreview()
+        method and non cancelable. This method does not require a class instance to run.
+     */
+    static bool loadHalfPreview(QByteArray& imgData, const QBuffer& inBuffer);
+
     /** Get the full decoded RAW picture. This is a more slower than loadHalfPreview() method
-        and non cancelable. This method do not require a class instance to run.
+        and non cancelable. This method does not require a class instance to run.
      */
     static bool loadFullImage(QImage& image, const QString& path, const RawDecodingSettings& settings = RawDecodingSettings());
 
@@ -125,13 +151,25 @@ public:
      */
     static QString librawVersion();
 
-    /** Return true if LibRaw use parallel demosaicing (libgomp support).
+    /** Return true or false if LibRaw use parallel demosaicing or not (libgomp support).
+     *  Return -1 if undefined.
      */
-    static bool librawUseGomp();
+    static int librawUseGomp();
 
-    /** Return true if LibRaw use RawSpeed codec.
+    /** Return true or false if LibRaw use RawSpeed codec or not.
+     *  Return -1 if undefined.
      */
-    static bool librawUseRawSpeed();
+    static int librawUseRawSpeed();
+
+    /** Return true or false if LibRaw use Demosaic Pack GPL2 or not.
+     *  Return -1 if undefined.
+     */
+    static int librawUseGPL2DemosaicPack();
+
+    /** Return true or false if LibRaw use Demosaic Pack GPL3 or not.
+     *  Return -1 if undefined.
+     */
+    static int librawUseGPL3DemosaicPack();
 
 public:
 
@@ -207,7 +245,7 @@ protected:
     virtual bool checkToCancelWaitingData();
 
     /** Re-implement this method to control the pseudo progress value during RAW decoding (when dcraw run with an
-        internal loop without feedback) with your proper environment. By default, this method do nothing.
+        internal loop without feedback) with your proper environment. By default, this method does nothing.
         Progress value average for this stage is 0%-n%, with 'n' == 40% max (see setWaitingDataProgress() method).
      */
     virtual void setWaitingDataProgress(double value);
